@@ -15,13 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <KLocalizedString>
-#include <qfiledialog.h>
-#include <QTemporaryFile>
-#include <QRegularExpression>
+#include "filterpmail.h"
 #include "mailimporter_debug.h"
 
-#include "filterpmail.h"
+#include <KLocalizedString>
+
+#include <QFileDialog>
+#include <QRegularExpression>
+#include <QTemporaryFile>
 
 using namespace MailImporter;
 
@@ -152,13 +153,12 @@ void FilterPMail::importMailFolder(const QString &file)
         char id[42];
     } pmm_head;
 
-    long l = 0;
     QFile f(file);
     if (!f.open(QIODevice::ReadOnly)) {
         filterInfo()->alert(i18n("Unable to open %1, skipping", file));
     } else {
         // Get folder name
-        l = f.read((char *)&pmm_head, sizeof(pmm_head));
+        long l = f.read((char *)&pmm_head, sizeof(pmm_head));
         QString folder(i18nc("define folder name when we will import pegasus mail", "PegasusMail-Import") + QLatin1Char('/'));
         if (folderParsed) {
             folder.append(getFolderName(QString::fromLatin1(pmm_head.id)));
@@ -277,7 +277,6 @@ bool FilterPMail::parseFolderMatrix(const QString &chosendir)
         filterInfo()->alert(i18n("Unable to open %1, skipping", chosendir + QLatin1String("hierarch.pm")));
         return false;
     } else {
-        QStringList tmpList;
         QByteArray tmpRead;
         while (!hierarch.atEnd()) {
             tmpRead = hierarch.readLine();
@@ -286,7 +285,11 @@ bool FilterPMail::parseFolderMatrix(const QString &chosendir)
             }
             QString tmpArray[5];
             tmpRead.remove(tmpRead.length() - 2, 2);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             QStringList tmpList = QString::fromLatin1(tmpRead).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+            QStringList tmpList = QString::fromLatin1(tmpRead).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
             int i = 0;
             QStringList::ConstIterator end(tmpList.constEnd());
             for (QStringList::ConstIterator it = tmpList.constBegin(); it != end; ++it, ++i) {
